@@ -93,10 +93,14 @@ void                 gda_connection_add_error_list (GdaConnection *cnc, GList *e
 gboolean             gda_connection_change_database (GdaConnection *cnc, const gchar *name);
 gboolean             gda_connection_create_database (GdaConnection *cnc, const gchar *name);
 gboolean             gda_connection_drop_database (GdaConnection *cnc, const gchar *name);
+gboolean             gda_connection_create_table (GdaConnection *cnc, const gchar *table_name,
+						  const GdaFieldAttributes *attributes[]);
+gboolean             gda_connection_drop_table (GdaConnection *cnc, const gchar *table_name);
 
 GList               *gda_connection_execute_command (GdaConnection *cnc,
 						     GdaCommand *cmd,
 						     GdaParameterList *params);
+gchar               *gda_connection_get_last_insert_id (GdaConnection *cnc, GdaDataModel *recset);
 GdaDataModel        *gda_connection_execute_single_command (GdaConnection *cnc,
 							    GdaCommand *cmd,
 							    GdaParameterList *params);
@@ -108,10 +112,13 @@ gboolean             gda_connection_begin_transaction (GdaConnection *cnc, GdaTr
 gboolean             gda_connection_commit_transaction (GdaConnection *cnc, GdaTransaction *xaction);
 gboolean             gda_connection_rollback_transaction (GdaConnection *cnc, GdaTransaction *xaction);
 
+gboolean             gda_connection_create_blob (GdaConnection *cnc, GdaBlob *blob);
+
 const GList         *gda_connection_get_errors (GdaConnection *cnc);
 
 typedef enum {
 	GDA_CONNECTION_FEATURE_AGGREGATES,
+	GDA_CONNECTION_FEATURE_BLOBS,
 	GDA_CONNECTION_FEATURE_INDEXES,
 	GDA_CONNECTION_FEATURE_INHERITANCE,
 	GDA_CONNECTION_FEATURE_NAMESPACES,
@@ -120,6 +127,7 @@ typedef enum {
 	GDA_CONNECTION_FEATURE_SQL,
 	GDA_CONNECTION_FEATURE_TRANSACTIONS,
 	GDA_CONNECTION_FEATURE_TRIGGERS,
+	GDA_CONNECTION_FEATURE_UPDATABLE_CURSOR,
 	GDA_CONNECTION_FEATURE_USERS,
 	GDA_CONNECTION_FEATURE_VIEWS,
 	GDA_CONNECTION_FEATURE_XML_QUERIES
