@@ -1,4 +1,4 @@
-/* A Bison parser, made from parser.y, by GNU bison 1.75.  */
+/* A Bison parser, made by GNU Bison 1.875.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
    Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.
@@ -23,9 +23,6 @@
    This special exception was added by the Free Software Foundation
    in version 1.24 of Bison.  */
 
-#ifndef BISON_PARSER_H
-# define BISON_PARSER_H
-
 /* Tokens.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
@@ -86,7 +83,8 @@
      L_PTYPE = 309,
      L_PISPARAM = 310,
      L_PDESCR = 311,
-     L_PNULLOK = 312
+     L_PNULLOK = 312,
+     L_UNSPECVAL = 313
    };
 #endif
 #define L_SELECT 258
@@ -144,13 +142,14 @@
 #define L_PISPARAM 310
 #define L_PDESCR 311
 #define L_PNULLOK 312
+#define L_UNSPECVAL 313
 
 
 
 
-#ifndef YYSTYPE
+#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
 #line 17 "parser.y"
-typedef union {
+typedef union YYSTYPE {
 void            *v;
 char            *str;
 int              i;
@@ -162,14 +161,15 @@ sql_condition   *c;
 sql_where       *w;
 param_spec      *ps;
 sql_order_field *of;
-} yystype;
-/* Line 1281 of /usr/share/bison/yacc.c.  */
-#line 168 "parser.h"
-# define YYSTYPE yystype
+} YYSTYPE;
+/* Line 1249 of yacc.c.  */
+#line 166 "parser.h"
+# define yystype YYSTYPE /* obsolescent; will be withdrawn */
+# define YYSTYPE_IS_DECLARED 1
+# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 extern YYSTYPE sqllval;
 
 
-#endif /* not BISON_PARSER_H */
 
